\name{pltS}
\alias{pltS}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Univariate posterior predictive inference}
\description{
  Plots marginal posterior predictive densities, hazard and survival
  function estimates based on
  \eqn{p(y \mid x) \equiv p(y_{n+1}=y \mid x_{n+1}=x, data)},
  marginalizing w.r.t. all model parameters and the random clustering.
  The function plots the posterior predictive for one or more
  coordinates of a vector valued response \eqn{y}.
}
\usage{
pltS <- function(idx=c(1,7),yl=NULL, xlim=NULL,
        col=NULL,sd=F,a=1.5, cex=0.7, lty=NULL, lwd=NULL,
        plt="p")
}
\arguments{
  \item{idx}{coordinates of a vector values response \eqn{y} to be
    plotted. Indices must be between 1 and p0.}
  \item{yl}{domain of the y-axis}
  \item{xlim}{domain of the x-axis}
  \item{col}{vector of as many colors as the size of idx.}
  \item{lg}{plot log density}
  \item{sd}{include plus/minus \eqn{a} posterior predictive standard
    deviation.}
  \item{a}{defines the step of standard deviation bounds. See
    previous item.}
  \item{lty}{vector of as many line type parameters as the size of idx.}
  \item{lwd}{vector of as many line width parameters as the size of idx.}
  \item{plt}{indicator for plotting the pdf ("p"), hazard ("h") or
       survival ("S") function.}
}
\details{
  Need to call \code{\link{ppmx}} first to carry out the posterior Markov
  chain Monte Carlo simulation. The function \code{pltS} uses
  the simulation output to produce the desired posterior predictive
  distribution.
  The function assumes the simulation output is saved in the current
  working directory. Change it by using \code{setwd} if necessary.
  
  The function is a simple R macro and can easily be modified for
  customized plots. See the use of the simulation output files
  py-S.mdp, py-pdf.mdp, py-pi.mdp and py-Si.mdp.
  
  See   \code{\link{ppmx-package}}  for a statement of the probability
  model.
}
\value{
  The function returns no value.
}
\references{
  the package uses the parametrization defined in:
  
    MacEachern, S.N. and Mueller, P. (1998).
  ``Estimating Mixture of Dirichlet Process Models,''
 Journal of Computational and Graphical Statistics, 7, 223--239.
}
\author{Peter Mueller \email{pm@wotan.mdacc.tmc.edu}}
\note{Careful, \code{mdp} writes temporary files
  into the current working directory. The same files
  are used by \code{pltS}, \code{plt.ex} and \code{plt.exy}
  to plot posterior predictive distributions and expectations.
}
\seealso{See also the R library \code{\link{DPpackage}}, at
  
  \url{http://student.kuleuven.be/~s0166452/software.html}.}
\examples{
\dontrun{
require("ppmx")

##################################################################
# prepare
##################################################################

## prepare the data file:

data(dtasim)
N <- nrow(dtasim)
## now select a sub-sample of n=200 data points for the example
n <- 200                             # desired sample size
idx <- sample(1:N,n)
Yin <- as.matrix( dtasim[idx,] )

## parameters for posterior predictive inference
xgrid <- read.table("py-x.mdp")      # cov combinations for prediction
nx <- nrow(xgrid)                    # n of covariate combinations
ny <- 50                             # size of grid for prediction

##################################################################
# call ppmx
##################################################################

ppmx(Yin,n.discard=500,n.iter=3000,
     p0=1,                           # 1-dim response
     p1=1,p2=2,p4=0,                 # 1 cont and 2 categorical cov's
     B.prior=1,S.prior=1,n.batch=50,
     xgrid=xgrid)                    # request posterior pred inference

##################################################################
# some inference summaries
##################################################################


pltS(idx=1:12,plt="p",lgd=T)          # plot post pred pdf
pltS(idx=1:12,plt="h")                # ... hazard
pltS(idx=1:12,plt="S",lgd=T)          # ... survival
pltS(idx=1:2,sd=T,plt="S",lgd=T)      # with pointwise post pred sd

## same thing using basic R plot commands.
S <-   matrix(scan("py-S.mdp"),byrow=T,ncol=ny) # S is a (nx x ny) matrix
pdf <- matrix(scan("py-p.mdp"),byrow=T,ncol=ny) # pdf    (nx x ny) matrix
ygrid <- scan("py-y.mdp")                       # grid for predictive
nx <- nrow(xgrid)

matplot(ygrid,t(S),type="l",xlab="Y",ylab="SURVIVAL BY COVARIATE",
        bty="l")
legend(x=80,y=max(S),col=0:nx,lty=0:nx,
       legend=
       c("COVARIATES",paste(xgrid[,1],xgrid[,2],xgrid[,3],sep="\t")),
       bty="n",cex=0.5)

matplot(ygrid,t(pdf),type="l",xlab="Y",ylab="DIST BY COVARIATE",
        bty="l")
legend(x=80,y=max(pdf),col=0:nx,lty=0:nx,
       legend=
       c("COVARIATES",paste(xgrid[,1],xgrid[,2],xgrid[,3],sep="\t")),
       bty="n",cex=0.5)

## same summaries using pltS(.) funcitons
}
}
